==> custom_pages-v1.12.8.zip: custom_pages/messages/el/model.php <==
<?php

return [
    'Abstract' => 'Σύνοψη',
    'Activate PHP based Pages and Snippets' => 'Ενεργοποιήστε σελίδες και αποσπάσματα που βασίζονται στην PHP',
    'Attach Files' => 'Επισύναψη Αρχείων',
    'Content' => 'Περιεχόμενο',
    'Empty <br />Container' => 'Κενό <br /> Container',
    'If disabled, existing php pages will still be online, but can\'t be created.' => 'Αν απενεργοποιηθεί, οι υπάρχουσες σελίδες php θα εξακολουθούν να είναι Σε συνδεδεμένες, αλλά δεν μπορούν να δημιουργηθούν.',
    'Label' => 'Επιγραφή',
    'Open in new window' => 'Άνοιγμα σε νέο παράθυρο',
    'PHP view path for custom space pages' => 'Διαδρομή προβολής PHP για σελίδες προσαρμοσμένου χώρου',
    'PHP view path for custom space snippets' => 'Διαδρομή προβολής PHP για αποσπάσματα προσαρμοσμένου χώρου',
    'PHP view path for global custom pages' => 'Διαδρομή προβολής PHP για παγκόσμιες προσαρμοσμένες σελίδες',
    'PHP view path for global custom snippets' => 'Διαδρομή προβολής PHP για παγκόσμια προσαρμοσμένα αποσπάσματα',
    'Placeholder name' => 'Όνομα Χωροθέτη',
    'The element name must contain at least two characters without spaces or special signs except \'_\'' => 'Το όνομα του στοιχείου πρέπει να περιέχει τουλάχιστον δύο χαρακτήρες χωρίς κενά ή ειδικά σύμβολα, εκτός από το \'_\'',
    'The given element name is already in use for this template.' => 'Το δοσμένο όνομα στοιχείου χρησιμοποιείται ήδη για αυτό το πρότυπο.',
    'The given view file path does not exist.' => 'Η δοσμένη διαδρομή προβολής αρχείου δεν υπάρχει.',
    'Url shortcut' => 'συντόμευση Url',
    'View' => 'Θέα',
    'Visibility' => 'Ορατότητα',
    'page' => 'Σελίδα',
    'snippet' => 'απόσπασμα',
    'Editors' => '',
    'Language-Based Visibility' => '',
    'Page-specific editors without full custom pages permission.' => '',
    'Visible to Group Members' => '',
];

==> custom_pages-v1.12.14.zip: custom_pages/messages/el/model.php <==
<?php

return [
    'Abstract' => 'Σύνοψη',
    'Activate PHP based Pages and Snippets' => 'Ενεργοποιήστε σελίδες και αποσπάσματα που βασίζονται στην PHP',
    'Attach Files' => 'Επισύναψη Αρχείων',
    'Content' => 'Περιεχόμενο',
    'Empty <br />Container' => 'Κενό <br /> Container',
    'If disabled, existing php pages will still be online, but can\'t be created.' => 'Αν απενεργοποιηθεί, οι υπάρχουσες σελίδες php θα εξακολουθούν να είναι Σε συνδεδεμένες, αλλά δεν μπορούν να δημιουργηθούν.',
    'Label' => 'Επιγραφή',
    'Open in new window' => 'Άνοιγμα σε νέο παράθυρο',
    'PHP view path for custom space pages' => 'Διαδρομή προβολής PHP για σελίδες προσαρμοσμένου χώρου',
    'PHP view path for custom space snippets' => 'Διαδρομή προβολής PHP για αποσπάσματα προσαρμοσμένου χώρου',
    'PHP view path for global custom pages' => 'Διαδρομή προβολής PHP για παγκόσμιες προσαρμοσμένες σελίδες',
    'PHP view path for global custom snippets' => 'Διαδρομή προβολής PHP για παγκόσμια προσαρμοσμένα αποσπάσματα',
    'Placeholder name' => 'Όνομα Χωροθέτη',
    'The element name must contain at least two characters without spaces or special signs except \'_\'' => 'Το όνομα του στοιχείου πρέπει να περιέχει τουλάχιστον δύο χαρακτήρες χωρίς κενά ή ειδικά σύμβολα, εκτός από το \'_\'',
    'The given element name is already in use for this template.' => 'Το δοσμένο όνομα στοιχείου χρησιμοποιείται ήδη για αυτό το πρότυπο.',
    'The given view file path does not exist.' => 'Η δοσμένη διαδρομή προβολής αρχείου δεν υπάρχει.',
    'Url shortcut' => 'συντόμευση Url',
    'View' => 'Θέα',
    'Visibility' => 'Ορατότητα',
    'page' => 'Σελίδα',
    'snippet' => 'απόσπασμα',
    'Editors' => '',
    'Hide in Navigation' => '',
    'Language-Based Visibility' => '',
    'Mobile App Users' => '',
    'Page-specific editors without full custom pages permission.' => '',
    'The element name is reserved, please choose another one.' => '',
    'Visible to Group Members' => '',
];
